Struct BreaksLeaf
pub struct BreaksLeaf { /* private fields */ }Trait Implementations
impl Clone for BreaksLeaf
impl Clone for BreaksLeaf
fn clone(&self) -> BreaksLeaf
fn clone(&self) -> BreaksLeaf
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for BreaksLeaf
impl Debug for BreaksLeaf
impl Default for BreaksLeaf
impl Default for BreaksLeaf
fn default() -> BreaksLeaf
fn default() -> BreaksLeaf
Returns the “default value” for a type. Read more
impl Leaf for BreaksLeaf
impl Leaf for BreaksLeaf
fn len(&self) -> usize
fn len(&self) -> usize
Measurement of leaf in base units.
A ‘base unit’ refers to the smallest discrete unit
by which a given concrete type can be indexed.
Concretely, for Rust’s String type the base unit is the byte.
fn is_ok_child(&self) -> bool
fn is_ok_child(&self) -> bool
Generally a minimum size requirement for leaves.
fn push_maybe_split(
&mut self,
other: &BreaksLeaf,
iv: Interval,
) -> Option<BreaksLeaf>
fn push_maybe_split( &mut self, other: &BreaksLeaf, iv: Interval, ) -> Option<BreaksLeaf>
Combine the part
other denoted by the Interval iv into self,
optionly splitting off a new Leaf if self would have become too big.
Returns either None if no splitting was needed, or Some(rest) if
rest was split off. Read moreimpl PartialEq for BreaksLeaf
impl PartialEq for BreaksLeaf
impl Eq for BreaksLeaf
impl StructuralPartialEq for BreaksLeaf